searchData={"items":[{"type":"module","title":"Ethers","doc":"high-level module providing a convenient and efficient interface for interacting\nwith the Ethereum blockchain using Elixir.\n\nThis module offers a simple API for common Ethereum operations such as deploying contracts,\nfetching current gas prices, and querying event logs.","ref":"Ethers.html"},{"type":"function","title":"Ethers.current_block_number/1","doc":"Returns the current block number of the blockchain.","ref":"Ethers.html#current_block_number/1"},{"type":"function","title":"Ethers.current_gas_price/0","doc":"Returns the current gas price from the RPC API","ref":"Ethers.html#current_gas_price/0"},{"type":"function","title":"Ethers.deploy/4","doc":"Deploys a contract to the blockchain.\n\nThis will return the transaction hash for the deployment transaction.\nTo get the address of your deployed contract, use `Ethers.deployed_address/2`.\n\nTo deploy a cotract you must have the binary related to it. It can either be a part of the ABI\nFile you have or as a separate file.","ref":"Ethers.html#deploy/4"},{"type":"function","title":"Parameters - Ethers.deploy/4","doc":"- contract_module_or_binary: Either the contract module which was already loaded or the compiled binary of the contract. The binary MUST be hex encoded.\n- contract_init: Constructor value for contract deployment. Use `CONTRACT_MODULE.constructor` function's output. If your contract does not have a constructor, you can pass an empty binary here.\n- params: Parameters for the transaction creating the contract.\n- opts: RPC and account options.","ref":"Ethers.html#deploy/4-parameters"},{"type":"function","title":"Ethers.deployed_address/2","doc":"Returns the address of the deployed contract if the deployment is finished and successful","ref":"Ethers.html#deployed_address/2"},{"type":"function","title":"Parameters - Ethers.deployed_address/2","doc":"- tx_hash: Hash of the Transaction which created a contract. \n- opts: RPC and account options.","ref":"Ethers.html#deployed_address/2-parameters"},{"type":"function","title":"Ethers.get_logs/3","doc":"Returns the event logs with the given filter","ref":"Ethers.html#get_logs/3"},{"type":"module","title":"Ethers.Contract","doc":"Dynamically creates modules for ABIs at compile time.","ref":"Ethers.Contract.html"},{"type":"module","title":"How to use - Ethers.Contract","doc":"You can simply create a new module and call `use Ethers.Contract` in it with the desired parameters.\n\n```elixir\ndefmodule MyProject.Contract do\n  use Ethers.Contract, abi_file: \"path/to/abi.json\"\nend\n```\n\nAfter this, the functions in your contracts should be accessible just by calling\n```elixir\ndata = MyProject.Contract.example_function(...)\n\n# Use data to handle eth_call\nEthers.Contract.call(data, to: \"0xADDRESS\", from: \"0xADDRESS\")\n{:ok, [...]}\n```","ref":"Ethers.Contract.html#module-how-to-use"},{"type":"module","title":"Valid `use` options - Ethers.Contract","doc":"- `abi`: Used to pass in the encoded/decoded json ABI of contract.\n- `abi_file`: Used to pass in the file path to the json ABI of contract.\n- `default_address`: Default contract deployed address. Can be overridden with `:to` option in every function.","ref":"Ethers.Contract.html#module-valid-use-options"},{"type":"module","title":"Execution Options - Ethers.Contract","doc":"These can be specified for all the actions by contracts.\n\n- `action`: Type of action for this function. Here are available values.\n  - `:call` uses `eth_call` to call the function and get the result. Will not change blockchain state or cost gas.\n  - `:send` uses `eth_sendTransaction` to call\n  - `:estimate_gas` uses `eth_estimateGas` to estimate the gas usage of this transaction.\n  - `:prepare` only prepares the `data` needed to make a transaction. Useful for Multicall.\n- `from`: The address of the wallet making this transaction. The private key should be loaded in the rpc server (For example: go-ethereum). Must be in `\"0x...\"` format.\n- `gas`: The gas limit for your transaction.\n- `rpc_client`: The RPC module implementing Ethereum JSON RPC functions. Defaults to `Ethereumex.HttpClient`\n- `rpc_opts`: Options to pass to the RCP client e.g. `:url`.\n- `to`: The address of the recipient contract. It will be defaulted to `default_address` if it was specified in Contract otherwise is required. Must be in `\"0x...\"` format.","ref":"Ethers.Contract.html#module-execution-options"},{"type":"type","title":"Ethers.Contract.action/0","doc":"","ref":"Ethers.Contract.html#t:action/0"},{"type":"type","title":"Ethers.Contract.t_event_output/0","doc":"","ref":"Ethers.Contract.html#t:t_event_output/0"},{"type":"type","title":"Ethers.Contract.t_function_output/0","doc":"","ref":"Ethers.Contract.html#t:t_function_output/0"},{"type":"module","title":"Ethers.Contracts.ENS.Resolver","doc":"Ethereum Name Service (ENS) Resolver Contract","ref":"Ethers.Contracts.ENS.Resolver.html"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.abi/3","doc":"Executes `ABI(bytes32 node, uint256 contentTypes)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#abi/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.abi/3","doc":"- node: `{:bytes, 32}`\n - contentTypes: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#abi/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.abi/3","doc":"- `{:uint, 256}`\n - `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#abi/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.abi!/3","doc":"Same as `abi/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#abi!/3"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.addr/2","doc":"Executes `addr(bytes32 node)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.addr/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.addr/2","doc":"- `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.addr/3","doc":"Executes `addr(bytes32 node, uint256 coinType)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#addr/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.addr/3","doc":"- node: `{:bytes, 32}`\n - coinType: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#addr/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.addr/3","doc":"- `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#addr/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.addr!/2","doc":"Same as `addr/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#addr!/2"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.addr!/3","doc":"Same as `addr/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#addr!/3"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.authorisations/4","doc":"Executes `authorisations(bytes32, address, address)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.authorisations/4","doc":"- `{:bytes, 32}`\n - `:address`\n - `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.authorisations/4","doc":"- `:bool`","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.authorisations!/4","doc":"Same as `authorisations/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations!/4"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.clear_dns_zone/2","doc":"Executes `clearDNSZone(bytes32 node)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.clear_dns_zone/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.clear_dns_zone/2","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.clear_dns_zone!/2","doc":"Same as `clear_dns_zone/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone!/2"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.constructor/1","doc":"Prepares contract constructor values.\n\nTo deploy a contracts see `Ethers.deploy/3`.","ref":"Ethers.Contracts.ENS.Resolver.html#constructor/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.constructor/1","doc":"- _ens: `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#constructor/1-parameters"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.contenthash/2","doc":"Executes `contenthash(bytes32 node)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.contenthash/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.contenthash/2","doc":"- `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.contenthash!/2","doc":"Same as `contenthash/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash!/2"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.default_address/0","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ENS.Resolver.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.dns_record/4","doc":"Executes `dnsRecord(bytes32 node, bytes32 name, uint16 resource)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.dns_record/4","doc":"- node: `{:bytes, 32}`\n - name: `{:bytes, 32}`\n - resource: `{:uint, 16}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.dns_record/4","doc":"- `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.dns_record!/4","doc":"Same as `dns_record/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record!/4"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.has_dns_records/3","doc":"Executes `hasDNSRecords(bytes32 node, bytes32 name)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.has_dns_records/3","doc":"- node: `{:bytes, 32}`\n - name: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.has_dns_records/3","doc":"- `:bool`","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.has_dns_records!/3","doc":"Same as `has_dns_records/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records!/3"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.interface_implementer/3","doc":"Executes `interfaceImplementer(bytes32 node, bytes4 interfaceID)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.interface_implementer/3","doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.interface_implementer/3","doc":"- `:address`","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.interface_implementer!/3","doc":"Same as `interface_implementer/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer!/3"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.multicall/2","doc":"Executes `multicall(bytes[] data)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.multicall/2","doc":"- data: `{:array, :bytes}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.multicall/2","doc":"- bytes: `:array`","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.multicall!/2","doc":"Same as `multicall/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#multicall!/2"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.name/2","doc":"Executes `name(bytes32 node)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#name/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.name/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#name/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.name/2","doc":"- `:string`","ref":"Ethers.Contracts.ENS.Resolver.html#name/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.name!/2","doc":"Same as `name/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#name!/2"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.pubkey/2","doc":"Executes `pubkey(bytes32 node)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.pubkey/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.pubkey/2","doc":"- `{:bytes, 32}`\n - `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.pubkey!/2","doc":"Same as `pubkey/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey!/2"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_abi/4","doc":"Executes `setABI(bytes32 node, uint256 contentType, bytes data)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_abi/4","doc":"- node: `{:bytes, 32}`\n - contentType: `{:uint, 256}`\n - data: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_abi/4","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_abi!/4","doc":"Same as `set_abi/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi!/4"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_addr/3","doc":"Executes `setAddr(bytes32 node, address a)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_addr/3","doc":"- node: `{:bytes, 32}`\n - a: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_addr/3","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_addr/4","doc":"Executes `setAddr(bytes32 node, uint256 coinType, bytes a)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_addr/4","doc":"- node: `{:bytes, 32}`\n - coinType: `{:uint, 256}`\n - a: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_addr/4","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_addr!/3","doc":"Same as `set_addr/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr!/3"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_addr!/4","doc":"Same as `set_addr/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr!/4"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_authorisation/4","doc":"Executes `setAuthorisation(bytes32 node, address target, bool isAuthorised)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_authorisation/4","doc":"- node: `{:bytes, 32}`\n - target: `:address`\n - isAuthorised: `:bool`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_authorisation/4","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_authorisation!/4","doc":"Same as `set_authorisation/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation!/4"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_contenthash/3","doc":"Executes `setContenthash(bytes32 node, bytes hash)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_contenthash/3","doc":"- node: `{:bytes, 32}`\n - hash: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_contenthash/3","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_contenthash!/3","doc":"Same as `set_contenthash/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash!/3"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_dns_records/3","doc":"Executes `setDNSRecords(bytes32 node, bytes data)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_dns_records/3","doc":"- node: `{:bytes, 32}`\n - data: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_dns_records/3","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_dns_records!/3","doc":"Same as `set_dns_records/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records!/3"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_interface/4","doc":"Executes `setInterface(bytes32 node, bytes4 interfaceID, address implementer)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_interface/4","doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`\n - implementer: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_interface/4","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_interface!/4","doc":"Same as `set_interface/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface!/4"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_name/3","doc":"Executes `setName(bytes32 node, string name)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_name/3","doc":"- node: `{:bytes, 32}`\n - name: `:string`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_name/3","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_name!/3","doc":"Same as `set_name/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_name!/3"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_pubkey/4","doc":"Executes `setPubkey(bytes32 node, bytes32 x, bytes32 y)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_pubkey/4","doc":"- node: `{:bytes, 32}`\n - x: `{:bytes, 32}`\n - y: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_pubkey/4","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_pubkey!/4","doc":"Same as `set_pubkey/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey!/4"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_text/4","doc":"Executes `setText(bytes32 node, string key, string value)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.set_text/4","doc":"- node: `{:bytes, 32}`\n - key: `:string`\n - value: `:string`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.set_text/4","doc":"","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.set_text!/4","doc":"Same as `set_text/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#set_text!/4"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.supports_interface/2","doc":"Executes `supportsInterface(bytes4 interfaceID)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.supports_interface/2","doc":"- interfaceID: `{:bytes, 4}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.supports_interface/2","doc":"- `:bool`","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.supports_interface!/2","doc":"Same as `supports_interface/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface!/2"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.text/3","doc":"Executes `text(bytes32 node, string key)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#text/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.text/3","doc":"- node: `{:bytes, 32}`\n - key: `:string`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.Resolver.html#text/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.Resolver.text/3","doc":"- `:string`","ref":"Ethers.Contracts.ENS.Resolver.html#text/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.text!/3","doc":"Same as `text/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.Resolver.html#text!/3"},{"type":"module","title":"Ethers.Contracts.ENS.Resolver.EventFilters","doc":"Events for `Ethers.Contracts.ENS.Resolver`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/3","doc":"Create event filter for `ABIChanged(bytes32 node, uint256 contentType)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/3","doc":"- node: `{:bytes, 32}`\n - contentType: `{:uint, 256}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/3","doc":"- node: `{:bytes, 32}`\n - contentType: `{:uint, 256}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/2","doc":"Create event filter for `AddrChanged(bytes32 node, address a)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/2","doc":"- node: `{:bytes, 32}`\n - a: `:address`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/2","doc":"Create event filter for `AddressChanged(bytes32 node, uint256 coinType, bytes newAddress)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/2","doc":"- node: `{:bytes, 32}`\n - coinType: `{:uint, 256}`\n - newAddress: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/4","doc":"Create event filter for `AuthorisationChanged(bytes32 node, address owner, address target, bool isAuthorised)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/4","doc":"- node: `{:bytes, 32}`\n - owner: `:address`\n - target: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/4-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/4","doc":"- node: `{:bytes, 32}`\n - owner: `:address`\n - target: `:address`\n - isAuthorised: `:bool`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/4-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/2","doc":"Create event filter for `ContenthashChanged(bytes32 node, bytes hash)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/2","doc":"- node: `{:bytes, 32}`\n - hash: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.default_address/0","doc":"","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/2","doc":"Create event filter for `DNSRecordChanged(bytes32 node, bytes name, uint16 resource, bytes record)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/2","doc":"- node: `{:bytes, 32}`\n - name: `:bytes`\n - resource: `{:uint, 16}`\n - record: `:bytes`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/2","doc":"Create event filter for `DNSRecordDeleted(bytes32 node, bytes name, uint16 resource)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/2","doc":"- node: `{:bytes, 32}`\n - name: `:bytes`\n - resource: `{:uint, 16}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/2","doc":"Create event filter for `DNSZoneCleared(bytes32 node)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/2","doc":"- node: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/3","doc":"Create event filter for `InterfaceChanged(bytes32 node, bytes4 interfaceID, address implementer)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/3","doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/3","doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`\n - implementer: `:address`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/2","doc":"Create event filter for `NameChanged(bytes32 node, string name)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/2","doc":"- node: `{:bytes, 32}`\n - name: `:string`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/2","doc":"Create event filter for `PubkeyChanged(bytes32 node, bytes32 x, bytes32 y)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/2","doc":"- node: `{:bytes, 32}`\n - x: `{:bytes, 32}`\n - y: `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/3","doc":"Create event filter for `TextChanged(bytes32 node, string indexedKey, string key)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/3","doc":"- node: `{:bytes, 32}`\n - indexedKey: `:string`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/3","doc":"- node: `{:bytes, 32}`\n - indexedKey: `:string`\n - key: `:string`","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/3-event-data-types"},{"type":"module","title":"Ethers.Event","doc":"EVM Event struct and helpers","ref":"Ethers.Event.html"},{"type":"function","title":"Ethers.Event.decode/2","doc":"Decodes a log entry with the given Event function selector and returns an Event struct","ref":"Ethers.Event.html#decode/2"},{"type":"type","title":"Ethers.Event.t/0","doc":"","ref":"Ethers.Event.html#t:t/0"},{"type":"module","title":"Ethers.NameService","doc":"Name Service resolution implementation","ref":"Ethers.NameService.html"},{"type":"function","title":"Ethers.NameService.name_hash/1","doc":"Implementation of namehash function in Elixir.\n\nSee https://docs.ens.domains/contract-api-reference/name-processing","ref":"Ethers.NameService.html#name_hash/1"},{"type":"function","title":"Examples - Ethers.NameService.name_hash/1","doc":"iex> Ethers.NameService.name_hash(\"foo.eth\")\n    Ethers.Utils.hex_decode!(\"0xde9b09fd7c5f901e23a3f19fecc54828e9c848539801e86591bd9801b019f84f\")\n\n    iex> Ethers.NameService.name_hash(\"alisina.eth\")\n    Ethers.Utils.hex_decode!(\"0x1b557b3901bef3a986febf001c3b19370b34064b130d49ea967bf150f6d23dfe\")","ref":"Ethers.NameService.html#name_hash/1-examples"},{"type":"function","title":"Ethers.NameService.resolve/2","doc":"Resolves a name on blockchain.","ref":"Ethers.NameService.html#resolve/2"},{"type":"function","title":"Parameters - Ethers.NameService.resolve/2","doc":"- name: Domain name to resolve. (Example: `foo.eth`)\n- opts: Resolve options.\n  - to: Resolver contract address. Defaults to ENS\n  - Accepts all other __Execution options__ from `Ethers.Contract`.","ref":"Ethers.NameService.html#resolve/2-parameters"},{"type":"function","title":"Examples - Ethers.NameService.resolve/2","doc":"```elixir\nEthers.NameService.resolve(\"vitalik.eth\")\n{:ok, \"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"}\n```","ref":"Ethers.NameService.html#resolve/2-examples"},{"type":"function","title":"Ethers.NameService.resolve!/2","doc":"Same as `resolve/2` but raises on errors.","ref":"Ethers.NameService.html#resolve!/2"},{"type":"function","title":"Examples - Ethers.NameService.resolve!/2","doc":"```elixir\nEthers.NameService.resolve!(\"vitalik.eth\")\n\"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"\n```","ref":"Ethers.NameService.html#resolve!/2-examples"},{"type":"module","title":"Ethers.RPC","doc":"RPC Methods for interacting with the Ethereum blockchain","ref":"Ethers.RPC.html"},{"type":"function","title":"Ethers.RPC.call/2","doc":"Makes an eth_call to with the given data and overrides, Than parses\nthe response using the selector in the params","ref":"Ethers.RPC.html#call/2"},{"type":"function","title":"Overrides - Ethers.RPC.call/2","doc":"This function accepts all of options which `Ethereumex.BaseClient.eth_send_transaction` accepts.\nNotable you can use these.\n\n- `:to`: Indicates recepient address. (Contract address in this case)","ref":"Ethers.RPC.html#call/2-overrides"},{"type":"function","title":"Options - Ethers.RPC.call/2","doc":"- `:block`: The block number or block alias. Defaults to `latest`\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)","ref":"Ethers.RPC.html#call/2-options"},{"type":"function","title":"Examples - Ethers.RPC.call/2","doc":"iex> Ethers.Contract.ERC20.total_supply() |> Ethers.Contract.call(to: \"0xa0b...ef6\")\n    {:ok, [100000000000000]}","ref":"Ethers.RPC.html#call/2-examples"},{"type":"function","title":"Ethers.RPC.estimate_gas/2","doc":"","ref":"Ethers.RPC.html#estimate_gas/2"},{"type":"function","title":"Ethers.RPC.eth_block_number/1","doc":"","ref":"Ethers.RPC.html#eth_block_number/1"},{"type":"function","title":"Ethers.RPC.eth_call/3","doc":"","ref":"Ethers.RPC.html#eth_call/3"},{"type":"function","title":"Ethers.RPC.eth_estimate_gas/2","doc":"","ref":"Ethers.RPC.html#eth_estimate_gas/2"},{"type":"function","title":"Ethers.RPC.eth_gas_price/1","doc":"","ref":"Ethers.RPC.html#eth_gas_price/1"},{"type":"function","title":"Ethers.RPC.eth_get_block_by_number/3","doc":"","ref":"Ethers.RPC.html#eth_get_block_by_number/3"},{"type":"function","title":"Ethers.RPC.eth_get_logs/2","doc":"","ref":"Ethers.RPC.html#eth_get_logs/2"},{"type":"function","title":"Ethers.RPC.eth_get_transaction_receipt/2","doc":"","ref":"Ethers.RPC.html#eth_get_transaction_receipt/2"},{"type":"function","title":"Ethers.RPC.eth_send_transaction/2","doc":"","ref":"Ethers.RPC.html#eth_send_transaction/2"},{"type":"function","title":"Ethers.RPC.send/2","doc":"Makes an eth_send to with the given data and overrides, Then returns the\ntransaction binary.","ref":"Ethers.RPC.html#send/2"},{"type":"function","title":"Overrides - Ethers.RPC.send/2","doc":"This function accepts all of options which `Ethereumex.BaseClient.eth_send_transaction` accepts.\nNotable you can use these.\n\n- `:to`: Indicates recepient address. (Contract address in this case)","ref":"Ethers.RPC.html#send/2-overrides"},{"type":"function","title":"Options - Ethers.RPC.send/2","doc":"- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)","ref":"Ethers.RPC.html#send/2-options"},{"type":"function","title":"Examples - Ethers.RPC.send/2","doc":"iex> Ethers.Contract.ERC20.transfer(\"0xff0...ea2\", 1000) |> Ethers.Contract.send(to: \"0xa0b...ef6\")\n    {:ok, transaction_bin}","ref":"Ethers.RPC.html#send/2-examples"},{"type":"module","title":"Ethers.Types","doc":"EVM types and compound type definitions","ref":"Ethers.Types.html"},{"type":"function","title":"Ethers.Types.default/1","doc":"Returns the default value in the given type if supported.","ref":"Ethers.Types.html#default/1"},{"type":"function","title":"Examples - Ethers.Types.default/1","doc":"iex> Ethers.Types.default(:address)\n    \"0x0000000000000000000000000000000000000000\"\n\n    iex> Ethers.Types.default({:int, 32})\n    0\n\n    iex> Ethers.Types.default({:uint, 8})\n    0\n\n    iex> Ethers.Types.default({:int, 128})\n    0\n\n    iex> Ethers.Types.default(:string)\n    \"\"\n\n    iex> Ethers.Types.default(:bytes)\n    \"\"\n\n    iex> Ethers.Types.default({:bytes, 8})\n     >","ref":"Ethers.Types.html#default/1-examples"},{"type":"function","title":"Ethers.Types.max/1","doc":"Returns the maximum possible value in the given type if supported.","ref":"Ethers.Types.html#max/1"},{"type":"function","title":"Examples - Ethers.Types.max/1","doc":"iex> Ethers.Types.max({:uint, 8})\n    255\n\n    iex> Ethers.Types.max({:int, 8})\n    127\n\n    iex> Ethers.Types.max({:uint, 16})\n    65535\n\n    iex> Ethers.Types.max({:int, 16})\n    32767","ref":"Ethers.Types.html#max/1-examples"},{"type":"function","title":"Ethers.Types.min/1","doc":"Returns the minimum possible value in the given type if supported.","ref":"Ethers.Types.html#min/1"},{"type":"function","title":"Examples - Ethers.Types.min/1","doc":"iex> Ethers.Types.min({:uint, 8})\n    0\n\n    iex> Ethers.Types.min({:int, 8})\n    -128\n\n    iex> Ethers.Types.min({:uint, 16})\n    0\n\n    iex> Ethers.Types.min({:int, 16})\n    -32768\n\n    iex> Ethers.Types.min({:int, 24})\n    -8388608","ref":"Ethers.Types.html#min/1-examples"},{"type":"function","title":"Ethers.Types.to_elixir_type/1","doc":"Converts EVM data types to typespecs for documentation","ref":"Ethers.Types.html#to_elixir_type/1"},{"type":"type","title":"Ethers.Types.t_address/0","doc":"Ethereum address in its hex format with 0x or in its binary format","ref":"Ethers.Types.html#t:t_address/0"},{"type":"type","title":"Examples - Ethers.Types.t_address/0","doc":"- `\"0xdAC17F958D2ee523a2206206994597C13D831ec7\"`\n- ` >`","ref":"Ethers.Types.html#t:t_address/0-examples"},{"type":"type","title":"Ethers.Types.t_hash/0","doc":"keccak hash in its hex format with 0x","ref":"Ethers.Types.html#t:t_hash/0"},{"type":"type","title":"Examples - Ethers.Types.t_hash/0","doc":"- `\"0xd4288c8e733eb71a39fe2e8dd4912ce54d8d26d9874f30309b26b4b071260422\"`","ref":"Ethers.Types.html#t:t_hash/0-examples"},{"type":"module","title":"Ethers.Utils","doc":"Utilities for interacting with ethereum blockchain","ref":"Ethers.Utils.html"},{"type":"function","title":"Ethers.Utils.date_to_block_number/3","doc":"Returns the nearest block number to a given date and time.","ref":"Ethers.Utils.html#date_to_block_number/3"},{"type":"function","title":"Parameters - Ethers.Utils.date_to_block_number/3","doc":"- date_or_date_time: Can be a `Date`, `DateTime` or an integer unix timestamp.\n- ref_block_number: A block number of reference. Can help faster search time if given.\n- opts: Optional extra options.\n  - acceptable_drift: Can be set to override the default acceptable_drift of 120 seconds.\n  - sample_size: Can be set to override the default sample_size of 10000 blocks.","ref":"Ethers.Utils.html#date_to_block_number/3-parameters"},{"type":"function","title":"Ethers.Utils.from_wei/1","doc":"Convert WEI to ETH","ref":"Ethers.Utils.html#from_wei/1"},{"type":"function","title":"Examples - Ethers.Utils.from_wei/1","doc":"iex> Ethers.Utils.from_wei(1000000000000000000)\n    1.0\n\n    iex> Ethers.Utils.from_wei(3140000000000000000)\n    3.14","ref":"Ethers.Utils.html#from_wei/1-examples"},{"type":"function","title":"Ethers.Utils.get_block_timestamp/2","doc":"Returns the timestamp for a given block number.\n\nThe block_number parameter can be a non negative integer or the hex encoded value of that integer.\n(The hex encoding *must* start with 0x prefix)","ref":"Ethers.Utils.html#get_block_timestamp/2"},{"type":"function","title":"Ethers.Utils.hex_decode/1","doc":"Decode from hex with (or without) 0x prefix.","ref":"Ethers.Utils.html#hex_decode/1"},{"type":"function","title":"Examples - Ethers.Utils.hex_decode/1","doc":"iex> Ethers.Utils.hex_decode(\"0x6574686572735f6578\")\n    {:ok, \"ethers_ex\"}\n\n    iex> Ethers.Utils.hex_decode(\"6574686572735f6578\")\n    {:ok, \"ethers_ex\"}\n\n    iex> Ethers.Utils.hex_decode(\"0x686\")\n    {:ok,  >}","ref":"Ethers.Utils.html#hex_decode/1-examples"},{"type":"function","title":"Ethers.Utils.hex_decode!/1","doc":"Same as `hex_decode/1` but raises on error","ref":"Ethers.Utils.html#hex_decode!/1"},{"type":"function","title":"Examples - Ethers.Utils.hex_decode!/1","doc":"iex> Ethers.Utils.hex_decode!(\"0x6574686572735f6578\")\n    \"ethers_ex\"\n\n    iex> Ethers.Utils.hex_decode!(\"6574686572735f6578\")\n    \"ethers_ex\"","ref":"Ethers.Utils.html#hex_decode!/1-examples"},{"type":"function","title":"Ethers.Utils.hex_encode/2","doc":"Encode to hex with 0x prefix.","ref":"Ethers.Utils.html#hex_encode/2"},{"type":"function","title":"Examples - Ethers.Utils.hex_encode/2","doc":"iex> Ethers.Utils.hex_encode(\"ethers_ex\")\n    \"0x6574686572735f6578\"","ref":"Ethers.Utils.html#hex_encode/2-examples"},{"type":"function","title":"Ethers.Utils.hex_to_integer/1","doc":"Converts a hexadecimal integer to integer form","ref":"Ethers.Utils.html#hex_to_integer/1"},{"type":"function","title":"Examples - Ethers.Utils.hex_to_integer/1","doc":"iex> Ethers.Utils.hex_to_integer(\"0x11111\")\n    {:ok, 69905}","ref":"Ethers.Utils.html#hex_to_integer/1-examples"},{"type":"function","title":"Ethers.Utils.hex_to_integer!/1","doc":"Same as `hex_to_integer/1` but raises on error","ref":"Ethers.Utils.html#hex_to_integer!/1"},{"type":"function","title":"Examples - Ethers.Utils.hex_to_integer!/1","doc":"iex> Ethers.Utils.hex_to_integer!(\"0x11111\")\n    69905","ref":"Ethers.Utils.html#hex_to_integer!/1-examples"},{"type":"function","title":"Ethers.Utils.human_arg/2","doc":"Reverse of `prepare_arg/2`","ref":"Ethers.Utils.html#human_arg/2"},{"type":"function","title":"Examples - Ethers.Utils.human_arg/2","doc":"iex> Ethers.Utils.human_arg(  234, 217, 8, 60, 117, 108, 194>>, :address)\n    \"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\" \n\n    iex> Ethers.Utils.human_arg(\"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\", :address)\n    \"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\"","ref":"Ethers.Utils.html#human_arg/2-examples"},{"type":"function","title":"Ethers.Utils.integer_to_hex/1","doc":"Converts integer to its hexadecimal form","ref":"Ethers.Utils.html#integer_to_hex/1"},{"type":"function","title":"Examples - Ethers.Utils.integer_to_hex/1","doc":"iex> Ethers.Utils.integer_to_hex(69905)\n    \"0x11111\"","ref":"Ethers.Utils.html#integer_to_hex/1-examples"},{"type":"function","title":"Ethers.Utils.maybe_add_gas_limit/2","doc":"Adds gas limit estimation to the parameters if not already exists\n\nIf option `mult` is given, a gas limit multiplied by `mult` divided by 1000 will be used.\nDefault for `mult` is 100. (1%)","ref":"Ethers.Utils.html#maybe_add_gas_limit/2"},{"type":"function","title":"Ethers.Utils.prepare_arg/2","doc":"Converts human readable argument to the form required for ABI encoding.\n\nFor example the addresses in Ethereum are represented by hex strings in human readable format\nbut are in 160-bit binaries in ABI form.","ref":"Ethers.Utils.html#prepare_arg/2"},{"type":"function","title":"Examples - Ethers.Utils.prepare_arg/2","doc":"iex> Ethers.Utils.prepare_arg(\"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\", :address)\n     >","ref":"Ethers.Utils.html#prepare_arg/2-examples"},{"type":"function","title":"Ethers.Utils.to_wei/1","doc":"Converts ETH to WEI","ref":"Ethers.Utils.html#to_wei/1"},{"type":"function","title":"Examples - Ethers.Utils.to_wei/1","doc":"iex> Ethers.Utils.to_wei(1)\n    1000000000000000000\n\n    iex> Ethers.Utils.to_wei(3.14)\n    3140000000000000000","ref":"Ethers.Utils.html#to_wei/1-examples"},{"type":"module","title":"Ethers.Contracts.ENS","doc":"Ethereum Name Service (ENS) Contract","ref":"Ethers.Contracts.ENS.html"},{"type":"function","title":"Ethers.Contracts.ENS.constructor/1","doc":"Prepares contract constructor values.\n\nTo deploy a contracts see `Ethers.deploy/3`.","ref":"Ethers.Contracts.ENS.html#constructor/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.constructor/1","doc":"- _old: `:address`","ref":"Ethers.Contracts.ENS.html#constructor/1-parameters"},{"type":"function","title":"Ethers.Contracts.ENS.default_address/0","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ENS.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ENS.is_approved_for_all/3","doc":"Executes `isApprovedForAll(address owner, address operator)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.is_approved_for_all/3","doc":"- owner: `:address`\n - operator: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.is_approved_for_all/3","doc":"- `:bool`","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.is_approved_for_all!/3","doc":"Same as `is_approved_for_all/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#is_approved_for_all!/3"},{"type":"function","title":"Ethers.Contracts.ENS.old/1","doc":"Executes `old()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#old/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.old/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#old/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.old/1","doc":"- `:address`","ref":"Ethers.Contracts.ENS.html#old/1-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.old!/1","doc":"Same as `old/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#old!/1"},{"type":"function","title":"Ethers.Contracts.ENS.owner/2","doc":"Executes `owner(bytes32 node)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#owner/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.owner/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#owner/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.owner/2","doc":"- `:address`","ref":"Ethers.Contracts.ENS.html#owner/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.owner!/2","doc":"Same as `owner/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#owner!/2"},{"type":"function","title":"Ethers.Contracts.ENS.record_exists/2","doc":"Executes `recordExists(bytes32 node)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#record_exists/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.record_exists/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#record_exists/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.record_exists/2","doc":"- `:bool`","ref":"Ethers.Contracts.ENS.html#record_exists/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.record_exists!/2","doc":"Same as `record_exists/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#record_exists!/2"},{"type":"function","title":"Ethers.Contracts.ENS.resolver/2","doc":"Executes `resolver(bytes32 node)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#resolver/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.resolver/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#resolver/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.resolver/2","doc":"- `:address`","ref":"Ethers.Contracts.ENS.html#resolver/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.resolver!/2","doc":"Same as `resolver/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#resolver!/2"},{"type":"function","title":"Ethers.Contracts.ENS.set_approval_for_all/3","doc":"Executes `setApprovalForAll(address operator, bool approved)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.set_approval_for_all/3","doc":"- operator: `:address`\n - approved: `:bool`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.set_approval_for_all/3","doc":"","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.set_approval_for_all!/3","doc":"Same as `set_approval_for_all/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#set_approval_for_all!/3"},{"type":"function","title":"Ethers.Contracts.ENS.set_owner/3","doc":"Executes `setOwner(bytes32 node, address owner)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_owner/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.set_owner/3","doc":"- node: `{:bytes, 32}`\n - owner: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_owner/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.set_owner/3","doc":"","ref":"Ethers.Contracts.ENS.html#set_owner/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.set_owner!/3","doc":"Same as `set_owner/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#set_owner!/3"},{"type":"function","title":"Ethers.Contracts.ENS.set_record/5","doc":"Executes `setRecord(bytes32 node, address owner, address resolver, uint64 ttl)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_record/5"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.set_record/5","doc":"- node: `{:bytes, 32}`\n - owner: `:address`\n - resolver: `:address`\n - ttl: `{:uint, 64}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_record/5-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.set_record/5","doc":"","ref":"Ethers.Contracts.ENS.html#set_record/5-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.set_record!/5","doc":"Same as `set_record/5` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#set_record!/5"},{"type":"function","title":"Ethers.Contracts.ENS.set_resolver/3","doc":"Executes `setResolver(bytes32 node, address resolver)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_resolver/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.set_resolver/3","doc":"- node: `{:bytes, 32}`\n - resolver: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_resolver/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.set_resolver/3","doc":"","ref":"Ethers.Contracts.ENS.html#set_resolver/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.set_resolver!/3","doc":"Same as `set_resolver/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#set_resolver!/3"},{"type":"function","title":"Ethers.Contracts.ENS.set_subnode_owner/4","doc":"Executes `setSubnodeOwner(bytes32 node, bytes32 label, address owner)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.set_subnode_owner/4","doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`\n - owner: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.set_subnode_owner/4","doc":"- `{:bytes, 32}`","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/4-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.set_subnode_owner!/4","doc":"Same as `set_subnode_owner/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#set_subnode_owner!/4"},{"type":"function","title":"Ethers.Contracts.ENS.set_subnode_record/6","doc":"Executes `setSubnodeRecord(bytes32 node, bytes32 label, address owner, address resolver, uint64 ttl)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_subnode_record/6"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.set_subnode_record/6","doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`\n - owner: `:address`\n - resolver: `:address`\n - ttl: `{:uint, 64}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_subnode_record/6-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.set_subnode_record/6","doc":"","ref":"Ethers.Contracts.ENS.html#set_subnode_record/6-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.set_subnode_record!/6","doc":"Same as `set_subnode_record/6` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#set_subnode_record!/6"},{"type":"function","title":"Ethers.Contracts.ENS.set_ttl/3","doc":"Executes `setTTL(bytes32 node, uint64 ttl)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_ttl/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.set_ttl/3","doc":"- node: `{:bytes, 32}`\n - ttl: `{:uint, 64}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#set_ttl/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.set_ttl/3","doc":"","ref":"Ethers.Contracts.ENS.html#set_ttl/3-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.set_ttl!/3","doc":"Same as `set_ttl/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#set_ttl!/3"},{"type":"function","title":"Ethers.Contracts.ENS.ttl/2","doc":"Executes `ttl(bytes32 node)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#ttl/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.ttl/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ENS.html#ttl/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ENS.ttl/2","doc":"- `{:uint, 64}`","ref":"Ethers.Contracts.ENS.html#ttl/2-return-types"},{"type":"function","title":"Ethers.Contracts.ENS.ttl!/2","doc":"Same as `ttl/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ENS.html#ttl!/2"},{"type":"module","title":"Ethers.Contracts.ERC1155","doc":"ERC1155 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-1155/","ref":"Ethers.Contracts.ERC1155.html"},{"type":"function","title":"Ethers.Contracts.ERC1155.balance_of/3","doc":"Executes `balanceOf(address account, uint256 id)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#balance_of/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.balance_of/3","doc":"- account: `:address`\n - id: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#balance_of/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC1155.balance_of/3","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC1155.html#balance_of/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.balance_of!/3","doc":"Same as `balance_of/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC1155.html#balance_of!/3"},{"type":"function","title":"Ethers.Contracts.ERC1155.balance_of_batch/3","doc":"Executes `balanceOfBatch(address[] accounts, uint256[] ids)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.balance_of_batch/3","doc":"- accounts: `{:array, :address}`\n - ids: `{:array, {:uint, 256}}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC1155.balance_of_batch/3","doc":"- `{:array, {:uint, 256}}`","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.balance_of_batch!/3","doc":"Same as `balance_of_batch/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch!/3"},{"type":"function","title":"Ethers.Contracts.ERC1155.constructor/0","doc":"Prepares contract constructor values.\n\nTo deploy a contracts see `Ethers.deploy/3`.","ref":"Ethers.Contracts.ERC1155.html#constructor/0"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.constructor/0","doc":"","ref":"Ethers.Contracts.ERC1155.html#constructor/0-parameters"},{"type":"function","title":"Ethers.Contracts.ERC1155.default_address/0","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ERC1155.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ERC1155.is_approved_for_all/3","doc":"Executes `isApprovedForAll(address account, address operator)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.is_approved_for_all/3","doc":"- account: `:address`\n - operator: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC1155.is_approved_for_all/3","doc":"- `:bool`","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.is_approved_for_all!/3","doc":"Same as `is_approved_for_all/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all!/3"},{"type":"function","title":"Ethers.Contracts.ERC1155.safe_batch_transfer_from/6","doc":"Executes `safeBatchTransferFrom(address from, address to, uint256[] ids, uint256[] amounts, bytes data)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/6"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.safe_batch_transfer_from/6","doc":"- from: `:address`\n - to: `:address`\n - ids: `{:array, {:uint, 256}}`\n - amounts: `{:array, {:uint, 256}}`\n - data: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/6-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC1155.safe_batch_transfer_from/6","doc":"","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/6-return-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.safe_batch_transfer_from!/6","doc":"Same as `safe_batch_transfer_from/6` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from!/6"},{"type":"function","title":"Ethers.Contracts.ERC1155.safe_transfer_from/6","doc":"Executes `safeTransferFrom(address from, address to, uint256 id, uint256 amount, bytes data)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/6"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.safe_transfer_from/6","doc":"- from: `:address`\n - to: `:address`\n - id: `{:uint, 256}`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/6-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC1155.safe_transfer_from/6","doc":"","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/6-return-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.safe_transfer_from!/6","doc":"Same as `safe_transfer_from/6` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from!/6"},{"type":"function","title":"Ethers.Contracts.ERC1155.set_approval_for_all/3","doc":"Executes `setApprovalForAll(address operator, bool approved)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.set_approval_for_all/3","doc":"- operator: `:address`\n - approved: `:bool`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC1155.set_approval_for_all/3","doc":"","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.set_approval_for_all!/3","doc":"Same as `set_approval_for_all/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all!/3"},{"type":"function","title":"Ethers.Contracts.ERC1155.supports_interface/2","doc":"Executes `supportsInterface(bytes4 interfaceId)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#supports_interface/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.supports_interface/2","doc":"- interfaceId: `{:bytes, 4}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#supports_interface/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC1155.supports_interface/2","doc":"- `:bool`","ref":"Ethers.Contracts.ERC1155.html#supports_interface/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.supports_interface!/2","doc":"Same as `supports_interface/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC1155.html#supports_interface!/2"},{"type":"function","title":"Ethers.Contracts.ERC1155.uri/2","doc":"Executes `uri(uint256 id)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#uri/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.uri/2","doc":"- id: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC1155.html#uri/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC1155.uri/2","doc":"- `:string`","ref":"Ethers.Contracts.ERC1155.html#uri/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.uri!/2","doc":"Same as `uri/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC1155.html#uri!/2"},{"type":"module","title":"Ethers.Contracts.ERC20","doc":"ERC20 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-20/","ref":"Ethers.Contracts.ERC20.html"},{"type":"function","title":"Ethers.Contracts.ERC20.allowance/3","doc":"Executes `allowance(address _owner, address _spender)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#allowance/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.allowance/3","doc":"- _owner: `:address`\n - _spender: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#allowance/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.allowance/3","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#allowance/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.allowance!/3","doc":"Same as `allowance/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#allowance!/3"},{"type":"function","title":"Ethers.Contracts.ERC20.approve/3","doc":"Executes `approve(address _spender, uint256 _value)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#approve/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.approve/3","doc":"- _spender: `:address`\n - _value: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#approve/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.approve/3","doc":"- `:bool`","ref":"Ethers.Contracts.ERC20.html#approve/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.approve!/3","doc":"Same as `approve/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#approve!/3"},{"type":"function","title":"Ethers.Contracts.ERC20.balance_of/2","doc":"Executes `balanceOf(address _owner)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#balance_of/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.balance_of/2","doc":"- _owner: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#balance_of/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.balance_of/2","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#balance_of/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.balance_of!/2","doc":"Same as `balance_of/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#balance_of!/2"},{"type":"function","title":"Ethers.Contracts.ERC20.constructor/0","doc":"Prepares contract constructor values.\n\nTo deploy a contracts see `Ethers.deploy/3`.","ref":"Ethers.Contracts.ERC20.html#constructor/0"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.constructor/0","doc":"","ref":"Ethers.Contracts.ERC20.html#constructor/0-parameters"},{"type":"function","title":"Ethers.Contracts.ERC20.decimals/1","doc":"Executes `decimals()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#decimals/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.decimals/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#decimals/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.decimals/1","doc":"- `{:uint, 8}`","ref":"Ethers.Contracts.ERC20.html#decimals/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.decimals!/1","doc":"Same as `decimals/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#decimals!/1"},{"type":"function","title":"Ethers.Contracts.ERC20.default_address/0","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ERC20.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ERC20.name/1","doc":"Executes `name()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#name/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.name/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#name/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.name/1","doc":"- `:string`","ref":"Ethers.Contracts.ERC20.html#name/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.name!/1","doc":"Same as `name/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#name!/1"},{"type":"function","title":"Ethers.Contracts.ERC20.symbol/1","doc":"Executes `symbol()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#symbol/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.symbol/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#symbol/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.symbol/1","doc":"- `:string`","ref":"Ethers.Contracts.ERC20.html#symbol/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.symbol!/1","doc":"Same as `symbol/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#symbol!/1"},{"type":"function","title":"Ethers.Contracts.ERC20.total_supply/1","doc":"Executes `totalSupply()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#total_supply/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.total_supply/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#total_supply/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.total_supply/1","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.html#total_supply/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.total_supply!/1","doc":"Same as `total_supply/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#total_supply!/1"},{"type":"function","title":"Ethers.Contracts.ERC20.transfer/3","doc":"Executes `transfer(address _to, uint256 _value)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#transfer/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.transfer/3","doc":"- _to: `:address`\n - _value: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#transfer/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.transfer/3","doc":"- `:bool`","ref":"Ethers.Contracts.ERC20.html#transfer/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.transfer!/3","doc":"Same as `transfer/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#transfer!/3"},{"type":"function","title":"Ethers.Contracts.ERC20.transfer_from/4","doc":"Executes `transferFrom(address _from, address _to, uint256 _value)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#transfer_from/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.transfer_from/4","doc":"- _from: `:address`\n - _to: `:address`\n - _value: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC20.html#transfer_from/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC20.transfer_from/4","doc":"- `:bool`","ref":"Ethers.Contracts.ERC20.html#transfer_from/4-return-types"},{"type":"function","title":"Ethers.Contracts.ERC20.transfer_from!/4","doc":"Same as `transfer_from/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC20.html#transfer_from!/4"},{"type":"module","title":"Ethers.Contracts.ERC721","doc":"ERC721 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-721/","ref":"Ethers.Contracts.ERC721.html"},{"type":"function","title":"Ethers.Contracts.ERC721.approve/3","doc":"Executes `approve(address to, uint256 tokenId)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#approve/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.approve/3","doc":"- to: `:address`\n - tokenId: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#approve/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.approve/3","doc":"","ref":"Ethers.Contracts.ERC721.html#approve/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.approve!/3","doc":"Same as `approve/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#approve!/3"},{"type":"function","title":"Ethers.Contracts.ERC721.balance_of/2","doc":"Executes `balanceOf(address owner)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#balance_of/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.balance_of/2","doc":"- owner: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#balance_of/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.balance_of/2","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#balance_of/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.balance_of!/2","doc":"Same as `balance_of/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#balance_of!/2"},{"type":"function","title":"Ethers.Contracts.ERC721.constructor/0","doc":"Prepares contract constructor values.\n\nTo deploy a contracts see `Ethers.deploy/3`.","ref":"Ethers.Contracts.ERC721.html#constructor/0"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.constructor/0","doc":"","ref":"Ethers.Contracts.ERC721.html#constructor/0-parameters"},{"type":"function","title":"Ethers.Contracts.ERC721.default_address/0","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ERC721.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ERC721.get_approved/2","doc":"Executes `getApproved(uint256 tokenId)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#get_approved/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.get_approved/2","doc":"- tokenId: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#get_approved/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.get_approved/2","doc":"- `:address`","ref":"Ethers.Contracts.ERC721.html#get_approved/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.get_approved!/2","doc":"Same as `get_approved/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#get_approved!/2"},{"type":"function","title":"Ethers.Contracts.ERC721.is_approved_for_all/3","doc":"Executes `isApprovedForAll(address owner, address operator)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.is_approved_for_all/3","doc":"- owner: `:address`\n - operator: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.is_approved_for_all/3","doc":"- `:bool`","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.is_approved_for_all!/3","doc":"Same as `is_approved_for_all/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all!/3"},{"type":"function","title":"Ethers.Contracts.ERC721.name/1","doc":"Executes `name()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#name/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.name/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#name/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.name/1","doc":"- `:string`","ref":"Ethers.Contracts.ERC721.html#name/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.name!/1","doc":"Same as `name/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#name!/1"},{"type":"function","title":"Ethers.Contracts.ERC721.owner_of/2","doc":"Executes `ownerOf(uint256 tokenId)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#owner_of/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.owner_of/2","doc":"- tokenId: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#owner_of/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.owner_of/2","doc":"- `:address`","ref":"Ethers.Contracts.ERC721.html#owner_of/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.owner_of!/2","doc":"Same as `owner_of/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#owner_of!/2"},{"type":"function","title":"Ethers.Contracts.ERC721.safe_transfer_from/4","doc":"Executes `safeTransferFrom(address from, address to, uint256 tokenId)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.safe_transfer_from/4","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.safe_transfer_from/4","doc":"","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.safe_transfer_from/5","doc":"Executes `safeTransferFrom(address from, address to, uint256 tokenId, bytes data)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/5"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.safe_transfer_from/5","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`\n - data: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/5-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.safe_transfer_from/5","doc":"","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/5-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.safe_transfer_from!/4","doc":"Same as `safe_transfer_from/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from!/4"},{"type":"function","title":"Ethers.Contracts.ERC721.safe_transfer_from!/5","doc":"Same as `safe_transfer_from/5` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from!/5"},{"type":"function","title":"Ethers.Contracts.ERC721.set_approval_for_all/3","doc":"Executes `setApprovalForAll(address operator, bool _approved)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.set_approval_for_all/3","doc":"- operator: `:address`\n - _approved: `:bool`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.set_approval_for_all/3","doc":"","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.set_approval_for_all!/3","doc":"Same as `set_approval_for_all/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all!/3"},{"type":"function","title":"Ethers.Contracts.ERC721.supports_interface/2","doc":"Executes `supportsInterface(bytes4 interfaceId)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#supports_interface/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.supports_interface/2","doc":"- interfaceId: `{:bytes, 4}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#supports_interface/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.supports_interface/2","doc":"- `:bool`","ref":"Ethers.Contracts.ERC721.html#supports_interface/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.supports_interface!/2","doc":"Same as `supports_interface/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#supports_interface!/2"},{"type":"function","title":"Ethers.Contracts.ERC721.symbol/1","doc":"Executes `symbol()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#symbol/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.symbol/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#symbol/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.symbol/1","doc":"- `:string`","ref":"Ethers.Contracts.ERC721.html#symbol/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.symbol!/1","doc":"Same as `symbol/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#symbol!/1"},{"type":"function","title":"Ethers.Contracts.ERC721.token_uri/2","doc":"Executes `tokenURI(uint256 tokenId)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#token_uri/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.token_uri/2","doc":"- tokenId: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#token_uri/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.token_uri/2","doc":"- `:string`","ref":"Ethers.Contracts.ERC721.html#token_uri/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.token_uri!/2","doc":"Same as `token_uri/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#token_uri!/2"},{"type":"function","title":"Ethers.Contracts.ERC721.total_supply/1","doc":"Executes `totalSupply()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#total_supply/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.total_supply/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#total_supply/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.total_supply/1","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.html#total_supply/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.total_supply!/1","doc":"Same as `total_supply/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#total_supply!/1"},{"type":"function","title":"Ethers.Contracts.ERC721.transfer_from/4","doc":"Executes `transferFrom(address from, address to, uint256 tokenId)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#transfer_from/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.transfer_from/4","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC721.html#transfer_from/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC721.transfer_from/4","doc":"","ref":"Ethers.Contracts.ERC721.html#transfer_from/4-return-types"},{"type":"function","title":"Ethers.Contracts.ERC721.transfer_from!/4","doc":"Same as `transfer_from/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC721.html#transfer_from!/4"},{"type":"module","title":"Ethers.Contracts.ERC777","doc":"ERC777 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-777/","ref":"Ethers.Contracts.ERC777.html"},{"type":"function","title":"Ethers.Contracts.ERC777.allowance/3","doc":"Executes `allowance(address holder, address spender)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#allowance/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.allowance/3","doc":"- holder: `:address`\n - spender: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#allowance/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.allowance/3","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#allowance/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.allowance!/3","doc":"Same as `allowance/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#allowance!/3"},{"type":"function","title":"Ethers.Contracts.ERC777.approve/3","doc":"Executes `approve(address spender, uint256 value)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#approve/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.approve/3","doc":"- spender: `:address`\n - value: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#approve/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.approve/3","doc":"- `:bool`","ref":"Ethers.Contracts.ERC777.html#approve/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.approve!/3","doc":"Same as `approve/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#approve!/3"},{"type":"function","title":"Ethers.Contracts.ERC777.authorize_operator/2","doc":"Executes `authorizeOperator(address operator)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#authorize_operator/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.authorize_operator/2","doc":"- operator: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#authorize_operator/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.authorize_operator/2","doc":"","ref":"Ethers.Contracts.ERC777.html#authorize_operator/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.authorize_operator!/2","doc":"Same as `authorize_operator/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#authorize_operator!/2"},{"type":"function","title":"Ethers.Contracts.ERC777.balance_of/2","doc":"Executes `balanceOf(address tokenHolder)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#balance_of/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.balance_of/2","doc":"- tokenHolder: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#balance_of/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.balance_of/2","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#balance_of/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.balance_of!/2","doc":"Same as `balance_of/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#balance_of!/2"},{"type":"function","title":"Ethers.Contracts.ERC777.burn/3","doc":"Executes `burn(uint256 amount, bytes data)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#burn/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.burn/3","doc":"- amount: `{:uint, 256}`\n - data: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#burn/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.burn/3","doc":"","ref":"Ethers.Contracts.ERC777.html#burn/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.burn!/3","doc":"Same as `burn/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#burn!/3"},{"type":"function","title":"Ethers.Contracts.ERC777.constructor/3","doc":"Prepares contract constructor values.\n\nTo deploy a contracts see `Ethers.deploy/3`.","ref":"Ethers.Contracts.ERC777.html#constructor/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.constructor/3","doc":"- name_: `:string`\n - symbol_: `:string`\n - defaultOperators_: `{:array, :address}`","ref":"Ethers.Contracts.ERC777.html#constructor/3-parameters"},{"type":"function","title":"Ethers.Contracts.ERC777.decimals/1","doc":"Executes `decimals()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#decimals/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.decimals/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#decimals/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.decimals/1","doc":"- `{:uint, 8}`","ref":"Ethers.Contracts.ERC777.html#decimals/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.decimals!/1","doc":"Same as `decimals/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#decimals!/1"},{"type":"function","title":"Ethers.Contracts.ERC777.default_address/0","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","ref":"Ethers.Contracts.ERC777.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ERC777.default_operators/1","doc":"Executes `defaultOperators()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#default_operators/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.default_operators/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#default_operators/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.default_operators/1","doc":"- address: `:array`","ref":"Ethers.Contracts.ERC777.html#default_operators/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.default_operators!/1","doc":"Same as `default_operators/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#default_operators!/1"},{"type":"function","title":"Ethers.Contracts.ERC777.granularity/1","doc":"Executes `granularity()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#granularity/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.granularity/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#granularity/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.granularity/1","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#granularity/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.granularity!/1","doc":"Same as `granularity/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#granularity!/1"},{"type":"function","title":"Ethers.Contracts.ERC777.is_operator_for/3","doc":"Executes `isOperatorFor(address operator, address tokenHolder)` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#is_operator_for/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.is_operator_for/3","doc":"- operator: `:address`\n - tokenHolder: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#is_operator_for/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.is_operator_for/3","doc":"- `:bool`","ref":"Ethers.Contracts.ERC777.html#is_operator_for/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.is_operator_for!/3","doc":"Same as `is_operator_for/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#is_operator_for!/3"},{"type":"function","title":"Ethers.Contracts.ERC777.name/1","doc":"Executes `name()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#name/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.name/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#name/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.name/1","doc":"- `:string`","ref":"Ethers.Contracts.ERC777.html#name/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.name!/1","doc":"Same as `name/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#name!/1"},{"type":"function","title":"Ethers.Contracts.ERC777.operator_burn/5","doc":"Executes `operatorBurn(address account, uint256 amount, bytes data, bytes operatorData)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#operator_burn/5"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.operator_burn/5","doc":"- account: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#operator_burn/5-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.operator_burn/5","doc":"","ref":"Ethers.Contracts.ERC777.html#operator_burn/5-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.operator_burn!/5","doc":"Same as `operator_burn/5` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#operator_burn!/5"},{"type":"function","title":"Ethers.Contracts.ERC777.operator_send/6","doc":"Executes `operatorSend(address sender, address recipient, uint256 amount, bytes data, bytes operatorData)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#operator_send/6"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.operator_send/6","doc":"- sender: `:address`\n - recipient: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#operator_send/6-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.operator_send/6","doc":"","ref":"Ethers.Contracts.ERC777.html#operator_send/6-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.operator_send!/6","doc":"Same as `operator_send/6` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#operator_send!/6"},{"type":"function","title":"Ethers.Contracts.ERC777.revoke_operator/2","doc":"Executes `revokeOperator(address operator)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#revoke_operator/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.revoke_operator/2","doc":"- operator: `:address`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#revoke_operator/2-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.revoke_operator/2","doc":"","ref":"Ethers.Contracts.ERC777.html#revoke_operator/2-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.revoke_operator!/2","doc":"Same as `revoke_operator/2` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#revoke_operator!/2"},{"type":"function","title":"Ethers.Contracts.ERC777.send/4","doc":"Executes `send(address recipient, uint256 amount, bytes data)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#send/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.send/4","doc":"- recipient: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#send/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.send/4","doc":"","ref":"Ethers.Contracts.ERC777.html#send/4-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.send!/4","doc":"Same as `send/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#send!/4"},{"type":"function","title":"Ethers.Contracts.ERC777.symbol/1","doc":"Executes `symbol()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#symbol/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.symbol/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#symbol/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.symbol/1","doc":"- `:string`","ref":"Ethers.Contracts.ERC777.html#symbol/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.symbol!/1","doc":"Same as `symbol/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#symbol!/1"},{"type":"function","title":"Ethers.Contracts.ERC777.total_supply/1","doc":"Executes `totalSupply()` on the contract.\n\nDefault action for this function is `:call`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#total_supply/1"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.total_supply/1","doc":"- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#total_supply/1-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.total_supply/1","doc":"- `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.html#total_supply/1-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.total_supply!/1","doc":"Same as `total_supply/1` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#total_supply!/1"},{"type":"function","title":"Ethers.Contracts.ERC777.transfer/3","doc":"Executes `transfer(address recipient, uint256 amount)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#transfer/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.transfer/3","doc":"- recipient: `:address`\n - amount: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#transfer/3-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.transfer/3","doc":"- `:bool`","ref":"Ethers.Contracts.ERC777.html#transfer/3-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.transfer!/3","doc":"Same as `transfer/3` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#transfer!/3"},{"type":"function","title":"Ethers.Contracts.ERC777.transfer_from/4","doc":"Executes `transferFrom(address holder, address recipient, uint256 amount)` on the contract.\n\nDefault action for this function is `:send`.\nTo override default action see Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#transfer_from/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.transfer_from/4","doc":"- holder: `:address`\n - recipient: `:address`\n - amount: `{:uint, 256}`\n- overrides: Overrides and options for the call. See Execution Options in `Ethers.Contract`.","ref":"Ethers.Contracts.ERC777.html#transfer_from/4-parameters"},{"type":"function","title":"Return Types - Ethers.Contracts.ERC777.transfer_from/4","doc":"- `:bool`","ref":"Ethers.Contracts.ERC777.html#transfer_from/4-return-types"},{"type":"function","title":"Ethers.Contracts.ERC777.transfer_from!/4","doc":"Same as `transfer_from/4` but raises `Ethers.ExecutionError` on errors.","ref":"Ethers.Contracts.ERC777.html#transfer_from!/4"},{"type":"module","title":"Ethers.Contracts.ENS.EventFilters","doc":"Events for `Ethers.Contracts.ENS`","ref":"Ethers.Contracts.ENS.EventFilters.html"},{"type":"function","title":"Ethers.Contracts.ENS.EventFilters.approval_for_all/3","doc":"Create event filter for `ApprovalForAll(address owner, address operator, bool approved)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.EventFilters.approval_for_all/3","doc":"- owner: `:address`\n - operator: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.EventFilters.approval_for_all/3","doc":"- owner: `:address`\n - operator: `:address`\n - approved: `:bool`","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.EventFilters.default_address/0","doc":"","ref":"Ethers.Contracts.ENS.EventFilters.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ENS.EventFilters.new_owner/3","doc":"Create event filter for `NewOwner(bytes32 node, bytes32 label, address owner)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.EventFilters.new_owner/3","doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.EventFilters.new_owner/3","doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`\n - owner: `:address`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.EventFilters.new_resolver/2","doc":"Create event filter for `NewResolver(bytes32 node, address resolver)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.EventFilters.new_resolver/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.EventFilters.new_resolver/2","doc":"- node: `{:bytes, 32}`\n - resolver: `:address`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.EventFilters.new_ttl/2","doc":"Create event filter for `NewTTL(bytes32 node, uint64 ttl)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.EventFilters.new_ttl/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.EventFilters.new_ttl/2","doc":"- node: `{:bytes, 32}`\n - ttl: `{:uint, 64}`","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/2-event-data-types"},{"type":"function","title":"Ethers.Contracts.ENS.EventFilters.transfer/2","doc":"Create event filter for `Transfer(bytes32 node, address owner)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ENS.EventFilters.transfer/2","doc":"- node: `{:bytes, 32}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ENS.EventFilters.transfer/2","doc":"- node: `{:bytes, 32}`\n - owner: `:address`","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/2-event-data-types"},{"type":"module","title":"Ethers.Contracts.ERC1155.EventFilters","doc":"Events for `Ethers.Contracts.ERC1155`","ref":"Ethers.Contracts.ERC1155.EventFilters.html"},{"type":"function","title":"Ethers.Contracts.ERC1155.EventFilters.approval_for_all/3","doc":"Create event filter for `ApprovalForAll(address account, address operator, bool approved)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.EventFilters.approval_for_all/3","doc":"- account: `:address`\n - operator: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC1155.EventFilters.approval_for_all/3","doc":"- account: `:address`\n - operator: `:address`\n - approved: `:bool`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.EventFilters.default_address/0","doc":"","ref":"Ethers.Contracts.ERC1155.EventFilters.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ERC1155.EventFilters.transfer_batch/4","doc":"Create event filter for `TransferBatch(address operator, address from, address to, uint256[] ids, uint256[] values)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.EventFilters.transfer_batch/4","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/4-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC1155.EventFilters.transfer_batch/4","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`\n - ids: `{:array, {:uint, 256}}`\n - values: `{:array, {:uint, 256}}`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/4-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.EventFilters.transfer_single/4","doc":"Create event filter for `TransferSingle(address operator, address from, address to, uint256 id, uint256 value)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.EventFilters.transfer_single/4","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/4-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC1155.EventFilters.transfer_single/4","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`\n - id: `{:uint, 256}`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/4-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC1155.EventFilters.uri/2","doc":"Create event filter for `URI(string value, uint256 id)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/2"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC1155.EventFilters.uri/2","doc":"- value: `{:uint, 256}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/2-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC1155.EventFilters.uri/2","doc":"- value: `:string`\n - id: `{:uint, 256}`","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/2-event-data-types"},{"type":"module","title":"Ethers.Contracts.ERC20.EventFilters","doc":"Events for `Ethers.Contracts.ERC20`","ref":"Ethers.Contracts.ERC20.EventFilters.html"},{"type":"function","title":"Ethers.Contracts.ERC20.EventFilters.approval/3","doc":"Create event filter for `Approval(address owner, address spender, uint256 value)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.EventFilters.approval/3","doc":"- owner: `:address`\n - spender: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC20.EventFilters.approval/3","doc":"- owner: `:address`\n - spender: `:address`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC20.EventFilters.default_address/0","doc":"","ref":"Ethers.Contracts.ERC20.EventFilters.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ERC20.EventFilters.transfer/3","doc":"Create event filter for `Transfer(address from, address to, uint256 value)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC20.EventFilters.transfer/3","doc":"- from: `:address`\n - to: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC20.EventFilters.transfer/3","doc":"- from: `:address`\n - to: `:address`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/3-event-data-types"},{"type":"module","title":"Ethers.Contracts.ERC721.EventFilters","doc":"Events for `Ethers.Contracts.ERC721`","ref":"Ethers.Contracts.ERC721.EventFilters.html"},{"type":"function","title":"Ethers.Contracts.ERC721.EventFilters.approval/4","doc":"Create event filter for `Approval(address owner, address approved, uint256 tokenId)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.EventFilters.approval/4","doc":"- owner: `:address`\n - approved: `:address`\n - tokenId: `{:uint, 256}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/4-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC721.EventFilters.approval/4","doc":"- owner: `:address`\n - approved: `:address`\n - tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/4-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC721.EventFilters.approval_for_all/3","doc":"Create event filter for `ApprovalForAll(address owner, address operator, bool approved)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.EventFilters.approval_for_all/3","doc":"- owner: `:address`\n - operator: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC721.EventFilters.approval_for_all/3","doc":"- owner: `:address`\n - operator: `:address`\n - approved: `:bool`","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC721.EventFilters.default_address/0","doc":"","ref":"Ethers.Contracts.ERC721.EventFilters.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ERC721.EventFilters.transfer/4","doc":"Create event filter for `Transfer(address from, address to, uint256 tokenId)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC721.EventFilters.transfer/4","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/4-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC721.EventFilters.transfer/4","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/4-event-data-types"},{"type":"module","title":"Ethers.Contracts.ERC777.EventFilters","doc":"Events for `Ethers.Contracts.ERC777`","ref":"Ethers.Contracts.ERC777.EventFilters.html"},{"type":"function","title":"Ethers.Contracts.ERC777.EventFilters.approval/3","doc":"Create event filter for `Approval(address owner, address spender, uint256 value)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.EventFilters.approval/3","doc":"- owner: `:address`\n - spender: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC777.EventFilters.approval/3","doc":"- owner: `:address`\n - spender: `:address`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC777.EventFilters.authorized_operator/3","doc":"Create event filter for `AuthorizedOperator(address operator, address tokenHolder)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.EventFilters.authorized_operator/3","doc":"- operator: `:address`\n - tokenHolder: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC777.EventFilters.authorized_operator/3","doc":"- operator: `:address`\n - tokenHolder: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC777.EventFilters.burned/3","doc":"Create event filter for `Burned(address operator, address from, uint256 amount, bytes data, bytes operatorData)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.EventFilters.burned/3","doc":"- operator: `:address`\n - from: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC777.EventFilters.burned/3","doc":"- operator: `:address`\n - from: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC777.EventFilters.default_address/0","doc":"","ref":"Ethers.Contracts.ERC777.EventFilters.html#default_address/0"},{"type":"function","title":"Ethers.Contracts.ERC777.EventFilters.minted/3","doc":"Create event filter for `Minted(address operator, address to, uint256 amount, bytes data, bytes operatorData)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.EventFilters.minted/3","doc":"- operator: `:address`\n - to: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC777.EventFilters.minted/3","doc":"- operator: `:address`\n - to: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC777.EventFilters.revoked_operator/3","doc":"Create event filter for `RevokedOperator(address operator, address tokenHolder)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.EventFilters.revoked_operator/3","doc":"- operator: `:address`\n - tokenHolder: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC777.EventFilters.revoked_operator/3","doc":"- operator: `:address`\n - tokenHolder: `:address`","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/3-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC777.EventFilters.sent/4","doc":"Create event filter for `Sent(address operator, address from, address to, uint256 amount, bytes data, bytes operatorData)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/4"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.EventFilters.sent/4","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/4-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC777.EventFilters.sent/4","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/4-event-data-types"},{"type":"function","title":"Ethers.Contracts.ERC777.EventFilters.transfer/3","doc":"Create event filter for `Transfer(address from, address to, uint256 value)` \n\nFor each indexed parameter you can either pass in the value you want to \nfilter or `nil` if you don't want to filter.","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/3"},{"type":"function","title":"Parameters - Ethers.Contracts.ERC777.EventFilters.transfer/3","doc":"- from: `:address`\n - to: `:address`\n- overrides: Overrides and options for the call.\n  - `address`: The address or list of addresses of the originating contract(s). (**Optional**)","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/3-parameters"},{"type":"function","title":"Event Data Types - Ethers.Contracts.ERC777.EventFilters.transfer/3","doc":"- from: `:address`\n - to: `:address`\n - value: `{:uint, 256}`","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/3-event-data-types"},{"type":"exception","title":"Ethers.ExecutionError","doc":"Execution Error Exception.\n\nThe Exception struct will have these values:\n\n- `message`: A human readable message for the exception.\n- `function`: The contract function which caused the exception.\n- `args`: The arguments for the function causing exception.\n- `error`: The error reason for the exception.","ref":"Ethers.ExecutionError.html"},{"type":"extras","title":"Introduction","doc":"# Elixir Ethers\n\n[![example workflow](https://github.com/alisinabh/elixir_ethers/actions/workflows/elixir.yml/badge.svg)](https://github.com/alisinabh/elixir_ethers)\n[![Coverage Status](https://coveralls.io/repos/github/alisinabh/elixir_ethers/badge.svg?branch=main)](https://coveralls.io/github/alisinabh/elixir_ethers?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/ethers.svg)](https://hex.pm/packages/ethers)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ethers/)\n[![License](https://img.shields.io/hexpm/l/ethers.svg)](https://github.com/alisinabh/elixir_ethers/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/alisinabh/elixir_ethers.svg)](https://github.com/alisinabh/elixir_ethers/commits/main)\n\nEthers is a comprehensive Web3 library for interacting with smart contracts on the Ethereum (Or any EVM based blockchain) using Elixir.\n\nHeavily inspired by the [ethers.js](https://github.com/ethers-io/ethers.js/), Ethers leverages the amazing Elixir meta-programming capabilities\nto generate Elixir modules for give smart contracts from their ABI. It also generates beautiful documentation for those modules which\ncan further help in development.","ref":"readme.html"},{"type":"extras","title":"Installation - Introduction","doc":"You can install the package by adding `ethers` to the list of dependencies in your `mix.exs` file::\n\n```elixir\ndef deps do\n  [\n    {:ethers, \"~> 0.0.6\"}\n  ]\nend\n```\n\nThe complete documentation is available on [hexdocs](https://hexdocs.pm/ethers).","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Introduction","doc":"To use Elixir Ethers, ensure you have a configured JSON-RPC endpoint.\nConfigure the endpoint using the following configuration parameter.\n\n\n```elixir\n# config.exs\nconfig :ethers,\n  rpc_client: Ethereumex.HttpClient, # Defaults to: Ethereumex.HttpClient\n  keccak_module: ExKeccak, # Defaults to: ExKeccak\n  json_module: Jason # Defaults to: Jason\n\n# If using Ethereumex, you need to specify a JSON-RPC server url here\nconfig :ethereumex, url: \"[URL_HERE]\"\n```\n\nYou can use [Cloudflare's Ethereum Gateway](https://developers.cloudflare.com/web3/ethereum-gateway/reference/supported-networks/) `https://cloudflare-eth.com/v1/mainnet` for the RPC URL.\n\nFor more configuration options, refer to [ethereumex](https://github.com/mana-ethereum/ethereumex#configuration).\n\nTo send transactions, you need a wallet client capable of signing transactions and exposing a JSON-RPC endpoint.","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Introduction","doc":"To use Elixir Ethers, you must have your contract's ABI in json format, which can be obtained from [etherscan.io](https://etherscan.io). \nThis library also contains standard contract interfaces such as `ERC20`, `ERC721` and some more by default (refer to built-in contracts in hex-doc).\n\nCreate a module for your contract as follows:\n\n```elixir\ndefmodule MyERC20Token do\n  use Ethers.Contract, \n    abi_file: \"path/to/abi.json\", \n    default_address: \"[Token address here (optional)]\"\nend\n```\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Calling contract functions - Introduction","doc":"After defining the module, all the functions can be called like any other Elixir module.\nThe documentation is also available giving the developer a first-class experience.\n\n```elixir\n# Calling functions on the blockchain\niex> MyERC20Token.balance_of(\"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\")\n{:ok, [654294510138460920346]}\n\n# Get the documentation of a function\niex> h MyERC20Token.balance_of\n                     def balance_of(owner, overrides \\\\ [])\n\n  @spec balance_of(Ethers.Types.t_address(), Keyword.t()) ::\n          {:ok, [non_neg_integer()]}\n          | {:ok, Ethers.Types.t_hash()}\n          | {:ok, Ethers.Contract.t_function_output()}\n          | {:error, term()}\n\nExecutes balanceOf(address _owner) on the contract.\n\nDefault action for this function is `:call`. To override default action see\nExecution Options in Ethers.Contract.","ref":"readme.html#calling-contract-functions"},{"type":"extras","title":"Parameters - Introduction","doc":"• _owner: `:address`\n  • overrides: Overrides and options for the call. See Execution Options in\n    Ethers.Contract.","ref":"readme.html#parameters"},{"type":"extras","title":"Return Types - Introduction","doc":"• {:uint, 256}\n```\n\n#","ref":"readme.html#return-types"},{"type":"extras","title":"Sending transaction - Introduction","doc":"Sending transactions is also straightforward, as Elixir Ethers automatically determines whether a function is a view function or a state-changing function, using `eth_call` or `eth_sendTransaction` accordingly.\nYou can override this behavior with the `:action` override.\n\nEnsure that you specify a `from` option to inform your client which account to use:\n\n\n```elixir\niex> MyERC20Token.transfer(\"0x[Recipient Address Here]\", Ethers.Utils.to_wei(1), from: \"0x[Your address here]\")\n{:ok, \"0xf313ff7ff54c6db80ad44c3ad58f72ff0fea7ce88e5e9304991ebd35a6e76000\"}\n```\n\n#","ref":"readme.html#sending-transaction"},{"type":"extras","title":"Getting Logs (Events) - Introduction","doc":"Elixir Ethers provides functionality for creating event filters and fetching events from the RPC endpoint using `eth_getLogs`. \nEach contract in Ethers generates an `EventFilters` module (e.g. `MyERC20Token.EventFilter`s) that can be used to create filters for events.\n\nTo create an event filter and use the [`Ethers.get_logs/3`](https://hexdocs.pm/ethers/Ethers.html#get_logs/3) function, follow this example:\n\n```elixir\niex> filter = MyERC20Token.EventFilters.transfer(\"0x[From Address Here]\", nil)\n\n# Also `nil` can be used for a parameter in EventFilters functions to show that it should not be filtered.\n# Then you can simply list the logs.\n\niex> Ethers.get_logs(filter)\n{:ok,\n [\n   %Ethers.Event{\n     address: \"0x5883c66ca442461d406f330775d42954bfcf7d92\",\n     block_hash: \"0x83de67fd285067b838790406ea68f21a3afbc0ade534047725b5ccfb904c9ed3\",\n     block_number: 17077047,\n     topics: [\"Transfer(address,address,uint256)\",\n      \"0x6b75d8af000000e20b7a7ddf000ba900b4009a80\",\n      \"0x230507f6a391ae5ac0ec124f1c5b8ce454fe3f3d\"],\n     topics_raw: [\"0xddf252ad1be2c89b69c2b068fc378daa952ba7f163c4a11628f55a4df523b3ef\",\n      \"0x0000000000000000000000006b75d8af000000e20b7a7ddf000ba900b4009a80\",\n      \"0x000000000000000000000000230507f6a391ae5ac0ec124f1c5b8ce454fe3f3d\"],\n     transaction_hash: \"0xaa6fb2e1bbb27f667e76b03e8cde23db694207e06b9aa810d4c20c1f109a58e5\",\n     transaction_index: 0,\n     data: [761112156078097834180608],\n     log_index: 0,\n     removed: false\n   },\n   %Ethers.Event{...},\n    ...\n ]}\n```\n\n#","ref":"readme.html#getting-logs-events"},{"type":"extras","title":"Resolving Ethereum names (ENS domains) using Ethers - Introduction","doc":"To resolve ENS or any other name service provider in the blockchain\nyou can simply use the [`Ethers.NameService`](https://hexdocs.pm/ethers/Ethers.NameService.html) module.\n\n```elixir\niex> Ethers.NameService.resolve(\"vitalik.eth\")\n{:ok, \"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"}\n```","ref":"readme.html#resolving-ethereum-names-ens-domains-using-ethers"},{"type":"extras","title":"Contributing - Introduction","doc":"All contributions to this project are very welcome. Please feel free to open issues and push PRs and even share your\nsuggestions.\n\nTo run the tests locally, you need to run [ganache](https://github.com/trufflesuite/ganache).\nAfter installing ganache, just run the following in a new window the you can run the tests on\nthe same machine.\n\n```\n> ganache --wallet.deterministic\n```","ref":"readme.html#contributing"},{"type":"extras","title":"Acknowledgements - Introduction","doc":"This project was not possible if it was not for the great [:ex_abi](https://github.com/poanetwork/ex_abi) library and its contributors.\n\nAlso a special thanks to the authors and contributors of [:ethereumex](https://github.com/mana-ethereum/ethereumex) library.","ref":"readme.html#acknowledgements"},{"type":"extras","title":"License - Introduction","doc":"[Apache License 2.0](https://github.com/alisinabh/elixir_ethers/blob/main/LICENSE)","ref":"readme.html#license"}],"content_type":"text/markdown"}